@@ -20,8 +20,8 @@ __author__ = 'Orsiris de Jong'
 __copyright__ = 'Copyright (C) 2020-2021 Orsiris de Jong'
 __description__ = 'Windows WMI query wrapper, wmi timezone converters'
 __licence__ = 'BSD 3 Clause'
-__version__ = '0.9.3'
-__build__ = '2021032401'
+__version__ = '0.9.6'
+__build__ = '2021051201'
 
 import logging
 import re
@@ -95,8 +95,8 @@ def query_wmi(query_str: str, namespace: str = 'cimv2', name: str = 'noname', de
               mp_queue: Union[Queue, SimpleQueue] = None, debug: bool = False,
               computer: str = 'localhost') -> Union[list, None]:
     """
-    Execute WMI queries that return pre-formatted python dictionnaries
-    Also allows to pass a queue for logging retunrs when using multiprocessing
+    Execute WMI queries that return pre-formatted python dictionaries
+    Also allows to pass a queue for logging returns when using multiprocessing
     """
     if mp_queue:
         logging_handler = QueueHandler(mp_queue)
@@ -113,9 +113,9 @@ def query_wmi(query_str: str, namespace: str = 'cimv2', name: str = 'noname', de
     # Multiprocessing also requires to pickle results
     # Since we cannot send wmi objects, we'll convert them to dict first using wmi_object_2_list_of_dict
 
-    # CoInitialize (and CoUninitialize) are needed when using WMI in threads, but not a multiprocessed childs
+    # CoInitialize (and CoUninitialize) are needed when using WMI in threads, but not a multiprocessing child
     # pythoncom.CoInitialize()
-    logger.log(logging.DEBUG, 'Running WMI query [%s].' % name)
+    local_logger.debug('Running WMI query [%s].' % name)
     # noinspection PyBroadException
 
     # Full moniker example
@@ -146,28 +146,34 @@ def query_wmi(query_str: str, namespace: str = 'cimv2', name: str = 'noname', de
             local_logger.critical('Bogus query path {}.'.format(namespace))
     except pywintypes.com_error:
         if can_be_skipped is not True:
-            local_logger.log(logging.WARNING, 'Cannot get WMI query (pywin) {}.'.format(name), exc_info=True)
-            local_logger.log(logging.DEBUG, 'Trace:', exc_info=True)
+            local_logger.warning('Cannot get WMI query (pywin) {}.'.format(name), exc_info=True)
+            local_logger.debug('Trace:', exc_info=True)
         else:
-            local_logger.log(logging.INFO, 'Cannot get WMI query (pywin) {}.'.format(name))
+            local_logger.info('Cannot get WMI query (pywin) {}.'.format(name))
     except wmi.x_access_denied:
         if can_be_skipped is not True:
-            local_logger.log(logging.WARNING, 'Cannot get WMI request (access) {}.'.format(name), exc_info=True)
-            local_logger.log(logging.DEBUG, 'Trace:', exc_info=True)
+            local_logger.warning('Cannot get WMI request (access) {}.'.format(name), exc_info=True)
+            local_logger.debug('Trace:', exc_info=True)
         else:
-            local_logger.log(logging.INFO, 'Cannot get WMI request (access) {}.'.format(name))
+            local_logger.info('Cannot get WMI request (access) {}.'.format(name))
+    except wmi.x_wmi:
+        if can_be_skipped is not True:
+            local_logger.warning('Cannot get WMI query (x_wmi) {}.'.format(name), exc_info=True)
+            local_logger.debug('Trace:', exc_info=True)
+        else:
+            local_logger.info('Cannot get WMI query (x_wmi) {}.'.format(name))
     except NameError:
         if can_be_skipped is not True:
-            local_logger.log(logging.WARNING, 'Cannot get WMI request (name) {}.'.format(name))
-            local_logger.log(logging.DEBUG, 'Trace:', exc_info=True)
+            local_logger.warning('Cannot get WMI request (name) {}.'.format(name))
+            local_logger.debug('Trace:', exc_info=True)
         else:
-            local_logger.log(logging.INFO, 'Cannot get WMI query (name) {}.'.format(name))
+            local_logger.info('Cannot get WMI query (name) {}.'.format(name))
     except Exception:
         if can_be_skipped is not True:
-            local_logger.log(logging.WARNING, 'Cannot get WMI request (uncaught) {}.'.format(name), exc_info=True)
-            local_logger.log(logging.DEBUG, 'Trace:', exc_info=True)
+            local_logger.warning('Cannot get non skippable WMI request (uncaught) {}.'.format(name))
+            local_logger.debug('Trace:', exc_info=True)
         else:
-            local_logger.log(logging.INFO, 'Cannot get WMI request (uncaught) {}.'.format(name))
+            local_logger.info('Cannot get WMI request (uncaught) {}.'.format(name))
     return None
 
     # Only needed when used in threaded environment
@@ -194,11 +200,15 @@ def get_wmi_timezone_bias() -> str:
         return "0"
 
 
-def datetime_utc_to_cim_timestamp(dt: datetime) -> str:
+def utc_datetime_to_cim_timestamp(dt: datetime, localize: bool = True) -> str:
     """
     Creates a WMI compatible timestamp from python datetime object
     """
-    timezonebias = get_wmi_timezone_bias()
+    if localize:
+        timezonebias = get_wmi_timezone_bias()
+    else:
+        timezonebias = 0
+
     cim_timestamp = dt.strftime('%Y%m%d%H%M%S.%f') + '+' + str(timezonebias)
     return cim_timestamp
 
@@ -226,14 +236,23 @@ def cim_timestamp_to_datetime(cim_timestamp: str, utc: bool = True) -> datetime:
     return timestamp
 
 
-def create_current_cim_timestamp(hour_offset: int = 0) -> str:
+def create_cim_timestamp_from_now(**kwargs) -> str:
     """
     Creates a WMI compatible timestamp, like "20200818124602.499324+120" from
     current datetime
     Current datetime can be increased / decreased by specifing an offset
 
-    :param hour_offset: adding an offset gives a offset hours in past timestamp
-    :return: str: timestamp
+    Future timestamps are achieved by specifying positive values, eg days=1
+    Past timestamps are achieved by specifying negative values, eg days=-1
+
+    Accepts all kwargs that timedelta accepts
     """
-    timestamp = (datetime.utcnow() - timedelta(hours=hour_offset))
-    return datetime_utc_to_cim_timestamp(timestamp)
+    dt = (datetime.utcnow() + timedelta(**kwargs))
+    return utc_datetime_to_cim_timestamp(dt)
+
+
+def create_current_cim_timestamp(hour_offset: int = 0) -> str:  # COMPAT <0.9.5
+    """
+    Compatibility wrapper for create_cim_timestamp_from_now
+    """
+    return create_cim_timestamp_from_now(hours=-hour_offset)
\ No newline at end of file
